Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/pytest_vulture/__init__.py | VultureError | 2 | 2 | 3 | 0.00%
src/pytest_vulture/__init__.py | (no class) | 5 | 5 | 3 | 0.00%
src/pytest_vulture/conf/base.py | Configuration | 6 | 6 | 0 | 0.00%
src/pytest_vulture/conf/base.py | (no class) | 17 | 17 | 0 | 0.00%
src/pytest_vulture/conf/package.py | PackageConfiguration | 14 | 14 | 4 | 0.00%
src/pytest_vulture/conf/package.py | (no class) | 19 | 19 | 0 | 0.00%
src/pytest_vulture/conf/reader.py | IniReader | 17 | 17 | 0 | 0.00%
src/pytest_vulture/conf/reader.py | (no class) | 16 | 16 | 4 | 0.00%
src/pytest_vulture/conf/vulture.py | VultureConfiguration | 27 | 27 | 2 | 0.00%
src/pytest_vulture/conf/vulture.py | (no class) | 27 | 27 | 0 | 0.00%
src/pytest_vulture/setup_manager.py | SetupManager | 83 | 83 | 4 | 0.00%
src/pytest_vulture/setup_manager.py | (no class) | 28 | 28 | 0 | 0.00%
src/pytest_vulture/vulture/comment.py | CommentFinder | 36 | 36 | 9 | 0.00%
src/pytest_vulture/vulture/comment.py | (no class) | 17 | 17 | 2 | 0.00%
src/pytest_vulture/vulture/manager.py | VultureManager | 27 | 27 | 0 | 0.00%
src/pytest_vulture/vulture/manager.py | (no class) | 22 | 22 | 0 | 0.00%
Total |  | 363 | 363 | 31 | 0.00%

No items found using the specified filter.

2 classes skipped due to complete coverage.